/****************************************************************************
Diese Programm MY_004412_2014 fast mehrere MegaCAD Befehle zu einem Befehlsaufruf
zusammen.
Aufgrund von Änderungen in der C-Schnittstelle von MegaCAD Version 2014 
mussten einge Anpassungen vorgenommen werden. siehe //!

1a. alle Elemente welche schwarz sind werden grün.
1b. alle Elemente welche nicht schwarz sind werden unsichtbar geschalten.
2. geänderte Elemente in Undoliste eintragen
3. AutoZomm auf sichbare Elemente
4. Attributleiste einstellen
5. Polyline aus den nun grünen Elementen erstellen.
6. Alle sichtbarmachen

Beispiel:
InterP	.\CIP\MY_004412_2014.cip 
	
Idee aus http://ww3.cad.de/foren/ubb/Forum22/HTML/004412.shtml

MegaCAD(R) ist eineingetragene Wortmarke der MEGATECH SOFTWARE GmbH

(C) 2013 JonCarpenter
Lizenz:  GPL v3

Version: 1.0 vom 2013-12-29 bis MegaCAD 2013
Version: 1.1 vom 2013-12-29 ab  MegaCAD 2014
*****************************************************************************/

#include "std.h"
#include "megatyp.h"
#include "megacad.h"

// FarbCode für Schwarz wegen Hintergrundfarbe 
#define MY_BLACK RGB(192,192,192)		//!	

short SearchBlack(
		void *pArg)
{
	t_entity  	*pEntity;			//Variable für Zeiger auf ElementDaten 
 	pEntity = (t_entity*) pArg;		//Zeiger auf ElementDaten zuweisen
	
	// prüfen ob Element Schwarz ist
	if(pEntity->attr.rgb == MY_BLACK)	//!
	{
 		// JA, Element Grün machen
		pEntity->attr.rgb = RGB_GREEN;	//!
		// Änderungen Element zuweisen
		ExChangeEntity(pEntity, pEntity->ecs);
	}
		else
	{
		//NEIN, Element Unsichtbar machen, alle anderen nicht ändern
		SetVisibility( &pEntity->id;, 1, IV_THESE_INVISI | IV_OTHERS_UNCHGD);
	}	
	
	return(CONTINUE_LOOP);
}

short AllVisible(
		void *pArg)
{
    t_entity  *pEntity;			//Variable für Zeiger auf ElementDaten 
    pEntity = (t_entity*) pArg;	//Zeiger auf ElementDaten zuweisen
	
	//Element Sichtbar machen, alle anderen nicht ändern
	SetVisibility( &pEntity->id;, 1, IV_THESE_VISI | IV_OTHERS_UNCHGD);

	return(CONTINUE_LOOP);
}

void SetAttributBar()
{
	ushort 		type;		// Variable für Typ
	t_attribs	attr;		// Variable für AttributStrucktur
	
	type = 0xf0; 			// Typ für Attributleiste
	
	GetAttributes(type, &attr); //Aktuelle Attribute der Leiste holen
	
	attr.grp = attr.grp;	// Gruppe 0-65535 						(0x01)
	attr.lay = attr.lay;	// Layer  0-65535 						(0x02)
	attr.pen = attr.pen;	// Stift 0-15 (Anzeige in Menü 1-16!) 	(0x04)
	attr.stl = attr.stl;	// Linientyp 1-14 						(0x08)
	attr.rgb = RGB_GREEN;	// Farbe 1-255 (bis MegaCAD 2013!) 		(0x10)	//!
	attr.wid = 5;			// Linienbreite 1-8 					(0x20)
	attr.iID = 0x10 | 0x20;	// ElementInfo wird Zweckentfremdet, gibt gültigkeit der Werte an (Flags)
	
	SetAttributes(type, &attr); //Attribute zuweisen
	
	return;
}

//Haupprogramm wird von MegaCAD aufgerufen
short MegaMain(
        char * file,
        char * args)
{  
	t_entity ent;		// Variable für ElementStrucktur
	t_mat44  ecs;
	
	ulong	filter1; 	// Variable für Elementfilter1
	ulong	filter2; 	// Variable für Elementfilter2
	
	SetCharSet(GT_ANSI);	//Zeichensatz einstellen

	// Selektionskriterium -> alle Elemente erlaubt
    filter1 = 0xffffffff;
	filter2 = 0xffffffff;
	
	WantInvisible(TRUE);	// wenn das Element Unsichtbar ist, wird der Elementtyp mit dem Wert von E_ISINVISI veroderert
	WantInvisible(FALSE);	// die Unsichtbarkeit hat keinen Einfluss auf den Wert des Elementtyps
	
	// Funtionstext und Maushilfe setzen
    SetFuncText("Alle Elemente unsichtbar, schwarze grün, Polyline zusammensetzen");
    MouseHelp("Element auswählen","Abbruch",HLP_INV(RED,WHITE,0));
			
	// Schleife über alle Elemente, Schwarze finden
	EntityLoop(filter1, filter2, SearchBlack, &ent, NULL, &ecs, 0);
	// alle geänderten Elemente in Undoliste eintragen
	savecount();
	// Autozoom auf die verbliebenen Elemente
	MegaCMD("AutoZoom");
	// Attribute in Attributleiste einstellen
	SetAttributBar();
	// MegaCADBefehl zum zusammensetzten einer Polyline aus vorhandenen Elementen aufrufen
	MegaCMD("PolyJoin");
	// Schleife über alle Elemente, alle Sichtbar machen
	EntityLoop(filter1, filter2, AllVisible, &ent, NULL, &ecs, 0);
	// Bildschirm neuzeichnen
	MegaCMD("Redraw");
	
    return(0);
}

